@@ -14,11 +14,11 @@ Games::Cards::ShuffleTrack - Track cards through shuffles and cuts
 
 =head1 VERSION
 
-Version 0.03_1
+Version 0.03_2
 
 =cut
 
-our $VERSION = '0.03_1';
+our $VERSION = '0.03_2';
 
 my $cut_limits = {
 	normal  => [0.19, 0.82], # on a 52 cards deck, cut between 10 and 43 cards
@@ -134,15 +134,28 @@ You can also specify the starting order of the deck among the following:
 
 	my $deck = Games::Cards::ShuffleTrack->new( 'fournier' );
 
+You can also set your own order:
+
+	my $pile = Games::Cards::ShufleTrack->new( [qw/10S JS QS KS AS/] );
+
 =cut
 
+# TODO: What happens if the user has a typo in the order?
 sub new {
 	my ($self, $order) = @_;
 	   $order ||= 'new_deck_order';
-	my $deck    = $decks->{ $order };
+
+	my $cards;
+	if ( ref $order eq 'ARRAY' ) {
+		$cards = $order;
+	}
+	else {
+		$cards = $decks->{ $order };
+	}
+
 	return bless {
-		'deck'        => $deck,
-		'original'    => $deck,
+		'deck'        => $cards,
+		'original'    => $cards,
 		'orientation' => 'down',
 	}, $self;
 }
@@ -260,51 +273,6 @@ sub overhand_shuffle {
 		   $self
 }
 
-=head3 Hindu Shuffle
-
-=head4 hindu_shuffle
-
-In a Hindu shuffle the cards are moved from hand to the other in packets, the result being similar to that of running cuts (the difference being that the packets in an overhand shuffle may be smaller than the ones in a running cut sequence).
-
-	$deck->hindu_shuffle;
-
-You can specify how many times you want to go through the deck (which is basically the same thing as calling the method that many times):
-
-	$deck->hindu_shuffle( 2 );
-
-The Hindu shuffle differs in result from the Overhand shuffle in that the packets are usually thicker; the reason for this is that while in the Overhand shuffle it's the thumb that grabs the cards (and the thumb can easily carry just one or two cards) in the Hindu shuffle it's more than one finger accomplishing this task, grabbing the deck by the sides, which makes it more difficult (hence, rare) to cut just one or two cards.
-
-=cut
-
-sub hindu_shuffle {
-	my $self  = shift;
-	my $times = shift || 1;
-
-	$self->_packet_transfer( 4, 10 );
-
-	return $times > 1 ?
-		   $self->hindu_shuffle( $times - 1 ) :
-		   $self
-}
-
-sub _packet_transfer {
-	my $self = shift;
-	my $min  = shift;
-	my $max  = shift;
-
-	my @deck = @{$self->get_deck};
-
-	my @new_deck;
-
-	while ( @deck ) {
-		if (@deck < $max) { $max = scalar @deck }
-		if (@deck < $min) { $min = scalar @deck }
-		unshift @new_deck, splice @deck, 0, _rand( $min, $max );
-	}
-
-	return $self->_set_deck( @new_deck );
-}
-
 
 =head4 run
 
@@ -364,6 +332,52 @@ sub run {
 }
 
 
+=head3 Hindu Shuffle
+
+=head4 hindu_shuffle
+
+In a Hindu shuffle the cards are moved from hand to the other in packets, the result being similar to that of running cuts (the difference being that the packets in an overhand shuffle may be smaller than the ones in a running cut sequence).
+
+	$deck->hindu_shuffle;
+
+You can specify how many times you want to go through the deck (which is basically the same thing as calling the method that many times):
+
+	$deck->hindu_shuffle( 2 );
+
+The Hindu shuffle differs in result from the Overhand shuffle in that the packets are usually thicker; the reason for this is that while in the Overhand shuffle it's the thumb that grabs the cards (and the thumb can easily carry just one or two cards) in the Hindu shuffle it's more than one finger accomplishing this task, grabbing the deck by the sides, which makes it more difficult (hence, rare) to cut just one or two cards.
+
+=cut
+
+sub hindu_shuffle {
+	my $self  = shift;
+	my $times = shift || 1;
+
+	$self->_packet_transfer( 4, 10 );
+
+	return $times > 1 ?
+		   $self->hindu_shuffle( $times - 1 ) :
+		   $self
+}
+
+sub _packet_transfer {
+	my $self = shift;
+	my $min  = shift;
+	my $max  = shift;
+
+	my @deck = @{$self->get_deck};
+
+	my @new_deck;
+
+	while ( @deck ) {
+		if (@deck < $max) { $max = scalar @deck }
+		if (@deck < $min) { $min = scalar @deck }
+		unshift @new_deck, splice @deck, 0, _rand( $min, $max );
+	}
+
+	return $self->_set_deck( @new_deck );
+}
+
+
 =head3 Riffle Shuffle
 
 =head4 riffle_shuffle
@@ -849,9 +863,16 @@ Inserts a card in a specified position in the deck. If the position isn't specif
 
 If the position doesn't exist the card will be replaced at the bottom of the deck.
 
+You can also add cards to negative positions, meaning that the resulting position will be that negative position:
+
+    # insert card so that it ends up being the last one in the deck
+	$deck->insert( $card, -1 );
+
+    # insert card so that it ends up being the 10th from the bottom
+	$deck->insert( $card, -10 );
+
 =cut
 
-# TODO: inserting in negative position?
 # TODO: what if the user inserts at position 0?
 sub insert {
 	my $self     = shift;
@@ -864,6 +885,9 @@ sub insert {
 	elsif ( $position > $self->deck_size ) {
 		$position = $self->deck_size + 1;
 	}
+	elsif ( $position < 0 ) {
+		$position = $self->deck_size + $position + 2;
+	}
 
 	splice @{$self->get_deck}, $position - 1, 0, $card;
 
@@ -904,6 +928,7 @@ You can still do a false deal to a pile:
 
 =cut
 
+# TODO: deal from an empty deck?
 sub deal {
 	my $self = shift;
 
@@ -921,6 +946,7 @@ sub deal {
 	my $position = $shortcuts->{$deal};
 
 	my $card = $self->remove( $position );
+
 	if ( defined $destination ) {
 		return $destination->put( $card );
 	}
